//-----------------------------------------------------------------------------
#include "Application.h"
#include "Context.h"
#include "view/View_Start.h"
#include <gst/gst.h>
//-----------------------------------------------------------------------------
int main(int argc, char* argv[])
{
   //initialize gstream
	gst_init (&argc, &argv);
	
  // Create application
  Application app(argc, argv);

  // Create context
  Context context(&app);

  // Create & show start view
  View_Start win(&context);
  win.initialize();
  win.show();

  // Execute application
  return app.exec();
}

//-----------------------------------------------------------------------------
